<?php
namespace Bricks\Integrations\Form\Actions;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Login extends Base {
	/**
	 * User login
	 *
	 * @since 1.0
	 */
	public function run( $form ) {
		$form_settings = $form->get_settings();
		$form_fields   = $form->get_fields();

		// Login response: WP_User on success, WP_Error on failure
		$login_response = wp_signon(
			[
				'user_login'    => $form_fields[ "form-field-{$form_settings['loginName']}" ] ?? false,
				'user_password' => $form_fields[ "form-field-{$form_settings['loginPassword']}" ] ?? false,
				'remember'      => isset( $form_fields[ "form-field-{$form_settings['loginRemember']}" ] ), // @since 1.9.2
			]
		);

		// Login error
		if ( is_wp_error( $login_response ) ) {
			$form->set_result(
				[
					'action'  => $this->name,
					'type'    => 'error',
					'message' => $form_settings['loginErrorMessage'] ?? $login_response->get_error_message(),
				]
			);

			return;
		}

		$form->set_result(
			[
				'action'         => $this->name,
				'type'           => 'success',
				'login_response' => $login_response,
			]
		);
	}
}
